from bdk.v1.requests import request_pb2 as _request_pb2
from bdk.v1.responses import response_pb2 as _response_pb2
from bdk.v1.services import book_pb2 as _book_pb2
from bdk.v1.services import library_pb2 as _library_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from grpc.health.v1 import health_pb2 as _health_pb2
import version_pb2 as _version_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar
DESCRIPTOR: _descriptor.FileDescriptor