from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class OAuthArgumentDescriptor(_message.Message):
    __slots__ = ('id', 'name', 'description')
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str

    def __init__(self, id: _Optional[str]=..., name: _Optional[str]=..., description: _Optional[str]=...) -> None:
        ...