from bdk.v1.requests import add_book_connection_pb2 as _add_book_connection_pb2
from bdk.v1.requests import book_connection_oauth_callback_pb2 as _book_connection_oauth_callback_pb2
from bdk.v1.requests import discover_procedures_pb2 as _discover_procedures_pb2
from bdk.v1.requests import environment_information_pb2 as _environment_information_pb2
from bdk.v1.requests import invoke_procedure_pb2 as _invoke_procedure_pb2
from bdk.v1.requests import remove_book_connection_pb2 as _remove_book_connection_pb2
from bdk.v1.requests import retrieve_book_pb2 as _retrieve_book_pb2
from bdk.v1.requests import retrieve_book_connections_pb2 as _retrieve_book_connections_pb2
from bdk.v1.requests import retrieve_book_procedures_pb2 as _retrieve_book_procedures_pb2
from bdk.v1.requests import retrieve_books_pb2 as _retrieve_books_pb2
from bdk.v1.requests import retrieve_books_connections_pb2 as _retrieve_books_connections_pb2
from bdk.v1.requests import retrieve_tags_pb2 as _retrieve_tags_pb2
from bdk.v1.requests import test_connection_pb2 as _test_connection_pb2
from bdk.v1.requests import update_book_connection_pb2 as _update_book_connection_pb2
from bdk.v1.requests import upgrade_book_connection_pb2 as _upgrade_book_connection_pb2
from bdk.v1.responses import book_connection_pb2 as _book_connection_pb2
from bdk.v1.responses import discover_procedures_pb2 as _discover_procedures_pb2_1
from bdk.v1.responses import environment_information_pb2 as _environment_information_pb2_1
from bdk.v1.responses import invoke_procedure_pb2 as _invoke_procedure_pb2_1
from bdk.v1.responses import remove_book_connection_pb2 as _remove_book_connection_pb2_1
from bdk.v1.responses import retrieve_book_pb2 as _retrieve_book_pb2_1
from bdk.v1.responses import retrieve_book_connections_pb2 as _retrieve_book_connections_pb2_1
from bdk.v1.responses import retrieve_book_procedures_pb2 as _retrieve_book_procedures_pb2_1
from bdk.v1.responses import retrieve_books_pb2 as _retrieve_books_pb2_1
from bdk.v1.responses import retrieve_books_connections_pb2 as _retrieve_books_connections_pb2_1
from bdk.v1.responses import retrieve_tags_pb2 as _retrieve_tags_pb2_1
from bdk.v1.responses import test_connection_pb2 as _test_connection_pb2_1
from bdk.v1.responses import upgrade_book_connection_pb2 as _upgrade_book_connection_pb2_1
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar
DESCRIPTOR: _descriptor.FileDescriptor