from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar
DESCRIPTOR: _descriptor.FileDescriptor

class EnvironmentInformationRequest(_message.Message):
    __slots__ = ()

    def __init__(self) -> None:
        ...