from bdk.v1 import v1_pb2 as _v1_pb2
from bdk.v2 import v2_pb2 as _v2_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from grpc.health.v1 import health_pb2 as _health_pb2
import version_pb2 as _version_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar
DESCRIPTOR: _descriptor.FileDescriptor